@@ -1,6 +1,5 @@
-import { create } from 'zustand';
-
-import { AdminInfo, UserInfo } from '../../../shared/hooks/api/types';
+import { createWithEqualityFn } from 'zustand/traditional';
+import type { AdminInfo, UserInfo } from '../../../shared/hooks/api/types';
 
 const defaultValues: StoreValues = {
   loading: false,
@@ -9,7 +8,7 @@ const defaultValues: StoreValues = {
   userInfo: undefined,
 };
 
-export const usePasswordResetStore = create<Store>((set) => ({
+export const usePasswordResetStore = createWithEqualityFn<Store>((set) => ({
   ...defaultValues,
   setState: (values) => set((old) => ({ ...old, ...values })),
   nextStep: (step) => set({ step }),
