@@ -1,7 +1,7 @@
 import './style.scss';
 
 import classNames from 'classnames';
-import { HTMLMotionProps, motion } from 'framer-motion';
+import { type HTMLMotionProps, motion } from 'motion/react';
 import { forwardRef, useMemo } from 'react';
 
 export const FloatingBox = forwardRef<HTMLDivElement, HTMLMotionProps<'div'>>(
