@@ -1,4 +1,4 @@
-import { avaliableThemes, ThemeKey } from './types';
+import { avaliableThemes, type ThemeKey } from './types';
 
 export const isThemeKey = (val: string): val is ThemeKey =>
   avaliableThemes.includes(val as ThemeKey);
