@@ -1,6 +1,6 @@
+import * as path from 'node:path';
 import react from '@vitejs/plugin-react-swc';
 import autoprefixer from 'autoprefixer';
-import * as path from 'path';
 import { defineConfig } from 'vite';
 
 // https://vitejs.dev/config/
@@ -19,10 +19,16 @@ export default defineConfig({
   },
   resolve: {
     alias: {
-      '@scssutils': path.resolve(__dirname, '/src/shared/scss/helpers'),
+      '@scss': path.resolve(__dirname, './src/shared/scss'),
+      '@scssutils': path.resolve(__dirname, './src/shared/defguard-ui/scss/helpers'),
     },
   },
   css: {
+    preprocessorOptions: {
+      scss: {
+        additionalData: `@use "@scssutils" as *;\n`,
+      },
+    },
     postcss: {
       plugins: [autoprefixer],
     },
